/**
 * Copyright (C) 2016-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.ui.tree;

import java.util.Arrays;
import java.util.List;

import org.dussan.vaadin.dtabs.demo.tabs.types.BottomTabTypes;
import org.dussan.vaadin.dtabs.demo.tabs.types.TopTabTypes;

public enum TabTypes
{

    DEFAULT( "", "" ), //
    TOP( TopTabTypes.DEFAULT.getPath(), TopTabTypes.DEFAULT.getDescription() ), //
    BOTTOM( BottomTabTypes.DEFAULT.getPath(), BottomTabTypes.DEFAULT.getDescription() );

    private final List<String> tabs;

    private TabTypes( String... tabs )
    {
        this.tabs = Arrays.asList( tabs );
    }

    private List<String> getValues()
    {
        return tabs;
    }

    public String getPath()
    {
        return tabs.get( 0 );
    }

    public String getDescription()
    {
        return tabs.get( 1 );
    }

    public static TabTypes fromString( String tab )
    {
        if ( tab != null )
        {
            for ( TabTypes tempTab : TabTypes.values() )
            {
                if ( tempTab.getValues()
                            .contains( tab ) )
                {
                    return tempTab;
                }
            }
        }
        return null;
    }

    @Override
    public String toString()
    {
        return getPath();
    }

}
