/**
 * Copyright (C) 2016-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.ui.tree;

import org.dussan.vaadin.dtabs.demo.tabs.BottomTabs;
import org.dussan.vaadin.dtabs.demo.tabs.TopTabs;
import org.dussan.vaadin.dtabs.demo.tabs.types.BottomTabTypes;
import org.dussan.vaadin.dtabs.demo.tabs.types.TopTabTypes;

import com.vaadin.data.Item;
import com.vaadin.event.ItemClickEvent;
import com.vaadin.event.ItemClickEvent.ItemClickListener;
import com.vaadin.server.Page;
import com.vaadin.ui.Tree;

public class TabsTree
    extends Tree
    implements Item.PropertySetChangeListener, ItemClickListener
{

    public static final String PATH_DELIMITER = "/";

    private static final long serialVersionUID = -3033650945759215541L;

    private boolean isAttached = false;

    private String selectedTab = null;

    public TabsTree()
    {
        selectedTab = new String();
        setImmediate( true );
        setNullSelectionAllowed( false );
    }

    public static boolean isNewTab( String tabType, String tab )
    {
        boolean isNew = false;
        switch ( TabTypes.fromString( tabType ) )
        {
            case TOP:
                isNew = TopTabTypes.fromString( tab )
                                   .isNew();
                break;
            case BOTTOM:
                isNew = BottomTabTypes.fromString( tab )
                                      .isNew();
                break;
            case DEFAULT:
            default:
                break;
        }
        return isNew;
    }

    private void init()
    {
        TopTabs.addTabs( this );
        BottomTabs.addTabs( this );

        this.setItemStyleGenerator( new ItemStyleGenerator()
        {
            private static final long serialVersionUID = -2292320405418615223L;

            @Override
            public String getStyle( Tree source, Object itemId )
            {
                String item = itemId.toString();
                if ( item.contains( PATH_DELIMITER )
                    && isNewTab( item.split( PATH_DELIMITER )[0], item.split( PATH_DELIMITER )[1] ) )
                {
                    return !item.equals( selectedTab ) ? "new" : "new-selected";
                }
                return null;
            }
        } );
    }

    private void process( String tabAddress, boolean refreshFragment )
    {
        if ( !selectedTab.equals( tabAddress ) )
        {
            unselect( selectedTab );

            String tabType = tabAddress;
            String tab = tabAddress;
            if ( tabAddress.contains( PATH_DELIMITER ) )
            {
                tabType = tabAddress.split( PATH_DELIMITER )[0];
                tab = tabAddress.split( PATH_DELIMITER )[1];
            }
            selectedTab = tabAddress;

            TabTypes type = TabTypes.fromString( tabType );
            switch ( type )
            {
                case TOP:
                    tab = TopTabTypes.fromString( tab )
                                     .getPath();
                    break;
                case BOTTOM:
                    tab = BottomTabTypes.fromString( tab )
                                        .getPath();
                    break;
                case DEFAULT:
                default:
                    type = TabTypes.DEFAULT;
                    tab = new String();
                    break;
            }

            tab = ( tab.isEmpty() || type.getPath()
                                         .equals( tab ) ) ? type.getPath() : ( type.getPath() + PATH_DELIMITER + tab );
            select( tab.isEmpty() ? null : tab );
            if ( refreshFragment )
            {
                Page.getCurrent()
                    .setUriFragment( tab );
            }
        }
    }

    @Override
    public void attach()
    {
        super.attach();
        if ( !isAttached )
        {
            isAttached = true;
            addItemClickListener( this );
            init();
        }
    }

    @Override
    public void detach()
    {
        super.detach();
        if ( isAttached )
        {
            isAttached = false;
            removeItemClickListener( this );
        }
    }

    @Override
    public void itemClick( ItemClickEvent event )
    {
        process( event.getItemId()
                      .toString(),
                 true );
    }

    @Override
    public void itemPropertySetChange( com.vaadin.data.Item.PropertySetChangeEvent event )
    {
        // nothing to do, only for activating function "setItemStyleGenerator"
    }

    public void processChangedFragment( String fragment )
    {
        process( fragment, false );
    }

}
